@@ -5,6 +5,8 @@
 # This program is free software. See terms in LICENSE file.
 
 """Calculate expedited permit process info"""
+import logging
+logger = logging.getLogger(__name__)
 
 import epw
 import geo
@@ -14,10 +16,13 @@ import vd
 import modules
 from math import degrees
 import sys
+if __name__ == "__main__":
+    logging.basicConfig(level=logging.INFO)
+
 try:
     import geomag
 except:
-    print "Warning: geomag not loaded.  Magnetic declination unavailible"
+    logger.warning("geomag not loaded.  Magnetic declination unavailible")
 
 def string_notes(system, run=0.0, station_class = 3):
     """page 5"""
@@ -99,12 +104,12 @@ def string_notes(system, run=0.0, station_class = 3):
                 notes.append("DC Operating Voltage: %s V" % round(i.array.v_dc(),1))
                 notes.append("System Max DC Voltage: %s V" % round(i.array.v_max(mintemp),1))
                 if i.array.v_max(mintemp) > 600:
-                    print "WARNING: Array exceeds 600V DC"
+                    logger.warning("WARNING: Array exceeds 600V DC")
                 notes.append("Pnom Ratio: %s" % round((i.array.p_max/i.p_aco),2))
                 if (i.array.v_dc(twopercentTemp) *.9) < i.mppt_low:
-                    print "WARNING: Array IV Knee drops out of Inverter range"
+                    logger.warning("WARNING: Array IV Knee drops out of Inverter range")
                 if (i.array.p_max/i.p_aco) < 1.1:
-                    print "WARNING: Array potentially undersized"
+                    logger.warning("WARNING: Array potentially undersized")
             notes.append("")
             di.pop(i.model)
         if i.array.v_max(mintemp) > aMax:
@@ -127,7 +132,10 @@ def string_notes(system, run=0.0, station_class = 3):
                 round(geomag.declination(dlat=system.place[0],dlon=system.place[1])))
     notes.append("Minimum Row space ratio: %s" % \
             round(system.min_row_space(1.0),2))
-    print "\n".join(notes)
+    if __name__ == '__main__':
+        print "\n".join(notes)
+    else:
+        logger.info("Plant Details:\n" + "\n".join(notes))
 
     print ""
     print "Minimum Bundle"
@@ -148,45 +156,47 @@ def micro_calcs(system,d,Vnominal=240):
     print vd.vd(sum([i.p_aco for i in system.shape])/Vnominal,d)
     pass
 
-def write_notes(system, Vnominal=240.0):
+def write_notes(system, filename='output', Vnominal=240.0):
     station_class = 1
     name, usaf = geo.closest_usaf( geo.zip_coordinates(system.zipcode), station_class)
     mintemp = epw.minimum(usaf)
     twopercentTemp = epw.twopercent(usaf)
     fields = []
     for i in set(system.shape):
+        moduleN = i.array.dump()['panel']
+        m = modules.Module(moduleN) 
         print "PV Module Ratings @ STC"
-        print "Module Make:", i.array.make
-        fields.append(('Text1ModuleMake',i.array.make))
-        print "Module Model:", i.array.model
-        fields.append(('Text1ModuleModel',i.array.model))
-        print "Max Power-Point Current (Imp):",i.array.i_mpp
-        fields.append(('MAX POWERPOINT CURRENT IMP',i.array.i_mpp))
-        print "Max Power-Point Voltage (Vmp):",i.array.v_mpp
-        fields.append(('MAX POWERPOINT VOLTAGE VMP',i.array.v_mpp))
-        print "Open-Circuit Voltage (v_oc):",i.array.v_oc
-        fields.append(('OPENCIRCUIT VOLTAGE VOC',i.array.v_oc))
-        print "Short-Circuit Current (i_sc):",i.array.i_sc
-        fields.append(('SHORTCIRCUIT CURRENT ISC',i.array.i_sc))
+        print "Module Make:", m.make
+        fields.append(('Text1ModuleMake',m.make))
+        print "Module Model:", m.model
+        fields.append(('Text1ModuleModel',m.model))
+        print "Max Power-Point Current (Imp):",m.i_mpp
+        fields.append(('MAX POWERPOINT CURRENT IMP',m.i_mpp))
+        print "Max Power-Point Voltage (Vmp):",m.v_mpp
+        fields.append(('MAX POWERPOINT VOLTAGE VMP',m.v_mpp))
+        print "Open-Circuit Voltage (v_oc):",m.v_oc
+        fields.append(('OPENCIRCUIT VOLTAGE VOC',m.v_oc))
+        print "Short-Circuit Current (i_sc):",m.i_sc
+        fields.append(('SHORTCIRCUIT CURRENT ISC',m.i_sc))
         fields.append(('MAX SERIES FUSE OCPD','15'))
-        print "Maximum Power (p_max):",i.array.p_max
-        fields.append(('MAXIMUM POWER PMAX',i.array.p_max))
-        print "Module Rated Max Voltage:",i.array.Vrated
-        fields.append(('MAX VOLTAGE TYP 600VDC',i.array.Vrated))
-        fields.append(('VOC TEMP COEFF mVoC or oC',round(i.array.tk_v_oc,2)))
+        print "Maximum Power (p_max):",m.p_max
+        fields.append(('MAXIMUM POWER PMAX',m.p_max))
+        print "Module Rated Max Voltage:",m.Vrated
+        fields.append(('MAX VOLTAGE TYP 600VDC',m.Vrated))
+        fields.append(('VOC TEMP COEFF mVoC or oC',round(m.tk_v_oc,2)))
         fields.append(('VOC TEMP COEFF mVoC','On'))
         print "Inverter Make:",i.make
         fields.append(('INVERTER MAKE',i.make))
         print "Inverter Model:",i.model
         fields.append(('INVERTER MODEL',i.model))
         print "Max Power", i.p_aco
-        fields.append(('MAX POWER  40oC',i.model))
+        fields.append(('MAX POWER  40oC',i.p_aco))
         fields.append(('NOMINAL AC VOLTAGE',240))
         print "Max AC Current: %s" % round(i.p_aco/Vnominal,2)
         fields.append(('MAX AC CURRENT', round(i.p_aco/Vnominal,2)))
-        fields.append(('MAX DC VOLT RATING',i.model))
-        print "Max AC OCPD Rating: %s" % ee.ocpSize(i.p_aco/Vnominal*1.25)
-        print "Max System Voltage:",round(i.array.v_max(mintemp),1)
+        fields.append(('MAX DC VOLT RATING',i.mppt_hi))
+        print "Max AC OCPD Rating: %s" % ee.ocp_size(i.p_aco/Vnominal*1.25)
+        print "Max System Voltage:",round(m.v_max(mintemp),1)
     print "AC Output Current: %s" % \
             round(sum([i.p_aco for i in system.shape])/Vnominal,2)
     fields.append(('AC OUTPUT CURRENT', \
@@ -203,7 +213,7 @@ def write_notes(system, Vnominal=240.0):
     fdf_file.close()
     import shlex
     from subprocess import call
-    cmd = shlex.split("pdftk Example2-Micro-Inverter.pdf fill_form data.fdf output output.pdf flatten")
+    cmd = shlex.split("pdftk Example2-Micro-Inverter.pdf fill_form data.fdf %s output.pdf flatten" % filename)
     rc = call(cmd)
 
 if __name__ == "__main__":
